//! Strongly typed git repository explorer library
//!
//! This library exposes a read-only view into a git repository.  To
//! get started, open an existing bare repo, and then call `sync()` to
//! build a cache of it.  Every time you want your view of the repo to
//! update, call `sync()` again.  If you want the sync operation to be
//! blocking, call `sync_blocking()` instead.
//!
//!

mod branch;
pub use branch::{Branch, BranchCommit};

mod commit;
pub use commit::Commit;

mod diff;
pub use diff::Diff;

mod repo;
pub use repo::Repository;
pub(crate) use repo::HashId;

use async_std::sync::{Arc, RwLock};
use std::sync::atomic::{AtomicUsize, Ordering};
